/*
  Blink several LEDs independently

  Several LEDs as in an array

  by noiasca
  2022-02-18 3046/274
  2022-01-17 3000/270
  2022-01-16 3014/268
*/

#include <Noiasca_led.h>               // download library from http://werner.rothschopf.net/microcontroller/202202_tools_led_en.htm
#include <utility/Noiasca_discrete.h>  // use the discrete pins on the Arduino/Microcontroller
#include <Noiasca_button.h>            // some tools to read buttons

BlinkPin blinkLed[] {13, 6, 5, 9};     // declare several blinking LED and assign pins
Button button[] {A0, A1, A2, A3};      // button connects pin with GND, "active LOW"

void setup() {
  Serial.begin(115200);
  for (auto &obj : blinkLed) {
    obj.begin();   // you have to call the .begin() method for each LED object
    obj.on();      // you can switch the blinking on in setup
  }
  for (auto &obj : button) {
    obj.begin();   // you have to call the .begin() method for each button
  }

  // you can set different blink intervals for your LEDs
  blinkLed[0].setOnInterval(2000);
  blinkLed[1].setOnInterval(200);
  blinkLed[2].setOffInterval(500);
  blinkLed[3].setOffInterval(200);
}

void loop() {
  // read the buttons
  if (button[0].wasPressed()) {
    Serial.println(F("button 0 was pressed, switch ON LED 0"));
    blinkLed[0].on();  // switch on LED
  }
  if (button[1].wasPressed()) {
    Serial.println(F("button 1 was pressed, switch OFF LED 0"));
    blinkLed[0].off(); // switch off LED
  }
  if (button[2].wasPressed()) {
    Serial.println(F("button 2 was pressed, toogle LED 2 (change from ON to OFF or vice versa)"));
    blinkLed[2].toggle(); // if button was pressed, toggle (change state) of blinkLed
  }
  if (button[3].wasPressed()) {
    Serial.println(F("button 2 was pressed, toogle LED 1 and LED 3 (change from ON to OFF or vice versa)"));
    blinkLed[1].toggle(); // if button was pressed, toggle (change state) of blinkLed
    blinkLed[3].toggle(); // if button was pressed, toggle (change state) of blinkLed
  }

  for (auto &obj : blinkLed) obj.update();   // you have to call update() for each LED
  // put other non blocking code here, to run repeatedly
}
