/*
  Alternating LED

  a pair of LEDs, alternating ON / OFF
  by noiasca
  2022-01-17 2844/213
  2022-01-16 2768/225
  2021-12-04 2768/225
*/

#include <Noiasca_led.h>               // download library from http://werner.rothschopf.net/microcontroller/202202_tools_led_en.htm
#include <utility/Noiasca_discrete.h>  // use the discrete pins on the Arduino/Microcontroller
#include <Noiasca_button.h>            // some tools to read buttons

AlternatingPin alternatingLed {2, 4};  // declare blinking LED and assign pins
Button button[] {A0, A1, A2};          // button connects pin with GND, "active LOW"


void setup() {
  Serial.begin(115200);

  alternatingLed.begin();    // you have to call the .begin() method for the LED pair
  alternatingLed.on();       // you can switch the blinking on in setup
  //alternatingLed.set(800, 400);  // you can change the ON times in ms for the LEDs individually
  for (auto &obj : button) {
    obj.begin();   // you have to call the .begin() method for each button
  }

  // you can set different blink intervals for your LEDs
  // alternatingLed.set(300, 300);
}

void loop() {
  // read the buttons
  if (button[0].wasPressed()) {
    Serial.println(F("button 0 was pressed, switch ON LED pair"));
    alternatingLed.on();     // switch on LED
  }
  if (button[1].wasPressed()) {
    Serial.println(F("button 1 was pressed, switch OFF LED pair"));
    alternatingLed.off();    // switch off LED
  }
  if (button[2].wasPressed()) {
    Serial.println(F("button 2 was pressed, toogle LED pair (change from ON to OFF or vice versa)"));
    alternatingLed.toggle(); // if button was pressed, toggle (change state) of blinkLed
  }

  alternatingLed.update();   // you have to call update() for each LED
  // put other non blocking code here, to run repeatedly
}
