/*
  Smooth LED

  This LED will
  - when switched on: get brighter slowly to the maximum and 
  - when switched off: dimm down slowly to 0
    
  you must connect the LED to a PWM enabled PIN 

  by noiasca
  2022-03-11   3754/235
  2022-01-17   2930/230
  2022-01-16   2880/231
  2021-12      2872/230
*/

#include <Noiasca_led.h>               // download library from https://werner.rothschopf.net/microcontroller/202202_tools_led_en.htm
#include <utility/Noiasca_discrete.h>  // use the discrete pins on the Arduino/Microcontroller
#include <Noiasca_button.h>            // some tools to read buttons

SmoothPin smoothLed {6};               // UNO PWM pins 3, 5, 6, 9, 10, 11
Button button[] {A0, A1, A2, A3};      // button connects pin with GND, "active LOW"

void setup() {
  Serial.begin(115200);
  smoothLed.begin();                   // you have to call the .begin() method for the LED pair
  smoothLed.on();                      // you can switch the LED on

  smoothLed.setOnInterval(30);         // you can modify the delay time for the smothing
  smoothLed.setOffInterval(5);         // you can modify the delay time for the smothing
  //smoothLed.setMaxBrightness(240);   // you can limit the maximum brightness. Highest value on Arduino is 255. Default 255.
  
  for (auto &obj : button) {
    obj.begin();                       // you have to call the .begin() method for each button
  }
}

void loop() {
  // read the buttons
  if (button[0].wasPressed()) {
    Serial.println(F("button 0 was pressed, switch ON LED"));
    smoothLed.on();                    // switch on LED
  }
  if (button[1].wasPressed()) {
    Serial.println(F("button 1 was pressed, switch OFF LED"));
    smoothLed.off();                   // switch off LED
  }
  if (button[2].wasPressed()) {
    Serial.println(F("button 2 was pressed, toogle LED (change from ON to OFF or vice versa)"));
    smoothLed.toggle();                // if button was pressed, toggle (change state) of blinkLed
  }
  if (button[3].wasPressed()) {
    byte maxBrightness = random(256);
    Serial.print(F("button 3 was pressed, new maxBrightness=")); Serial.println(maxBrightness);
    smoothLed.setMaxBrightness(maxBrightness);   // if button was pressed, change maxBrightness
  }

  smoothLed.update();                  // you have to call update() for the LED
}
