/*
  Pulse Led

  lights up for a specific time

  retriggerable monoflop
  
  by noiasca
  2022-01-17 2682/227
  2022-01-16 2648/227
  2021-12    2656/227
*/

#include <Noiasca_led.h>               // download library from http://werner.rothschopf.net/microcontroller/202202_tools_led_en.htm
#include <utility/Noiasca_discrete.h>  // use the discrete pins on the Arduino/Microcontroller
#include <Noiasca_button.h>            // some tools to read buttons
                                       
PulsePin pulseLed {13};                // any output pin
//PulsePin pulseLed {13, LOW};         // if the pin should be LOW active, set second parameter
Button button[] {A0, A1, A2, A3};      // button connects pin with GND, "active LOW"

void setup() {
  Serial.begin(115200);
  pulseLed.begin();                    // you have to call the .begin() method for the LED pair
  pulseLed.on();                       // you can switch the LED on

  pulseLed.setOnInterval(700);         // you can modify the delay time for the pulsing. Default value is 50.
 
  for (auto &obj : button) {
    obj.begin();   // you have to call the .begin() method for each button
  }
}

void loop() {
  // read the buttons
  if (button[0].wasPressed()) {
    Serial.println(F("button 0 was pressed, switch ON LED"));
    pulseLed.on();                     // switch on LED
  }
  if (button[1].wasPressed()) {
    Serial.println(F("button 1 was pressed, switch OFF LED"));
    pulseLed.off();                   // switch off LED
  }
  if (button[2].wasPressed()) {
    Serial.println(F("button 2 was pressed, toogle LED (change from ON to OFF or vice versa)"));
    pulseLed.toggle();                // if button was pressed, toggle (change state) of LED
  }

  pulseLed.update();                  // you have to call update() for the LED
}
