/*
  Flicker LED

  a flicker LED could be used to simulate a "fire".
    
  you must connect the LED to a PWM enabled PIN 

  by noiasca
  2022-01-17     3412/229
  2022-01-16     3394/230
  2021           3382/229
*/

#include <Noiasca_led.h>               // download library from http://werner.rothschopf.net/microcontroller/202202_tools_led_en.htm
#include <utility/Noiasca_discrete.h>  // use the discrete pins on the Arduino/Microcontroller
#include <Noiasca_button.h>            // here we have some read buttons

FlickerPin flickerLed {3};             // UNO PWM pins 3, 5, 6, 9, 10, 11
Button button[] {A0, A1, A2, A3};      // button connects pin with GND, "active LOW"

void setup() {
  Serial.begin(115200);
  flickerLed.begin();                  // you have to call the .begin() method for the LED pair
  flickerLed.on();                     // you can switch the LED on

  for (auto &obj : button) {
    obj.begin();                       // you have to call the .begin() method for each button
  }
}

void loop() {
  // read the buttons
  if (button[0].wasPressed()) {
    Serial.println(F("button 0 was pressed, switch ON LED"));
    flickerLed.on();                   // switch on LED
  }
  if (button[1].wasPressed()) {
    Serial.println(F("button 1 was pressed, switch OFF LED"));
    flickerLed.off();                  // switch off LED
  }
  if (button[2].wasPressed()) {
    Serial.println(F("button 2 was pressed, toogle LED (change from ON to OFF or vice versa)"));
    flickerLed.toggle();               // if button was pressed, toggle (change state) of LED
  }

  flickerLed.update();                 // you have to call update() for the LED
}
