/*
  a Single traffic light

  by noiasca
  2022-01-17 3274/252
  2022-01-16 3178/267
  2021-12-04
*/

#include <Noiasca_led.h>               // download library from http://werner.rothschopf.net/microcontroller/202202_tools_led_en.htm
#include <utility/Noiasca_discrete.h>  // use the discrete pins on the Arduino/Microcontroller
#include <Noiasca_button.h>            // some tools to read buttons

TrafficlightPin trafficlight {2, 3, 5};// GPIO red, GPIO yellow, GPIO green
// Trafficlight trafficlight {2, 255, 5};// GPIO red, (yellow not used), GPIO green
Button button[] {A0, A1, A2, A3};      // button connects pin with GND, "active LOW"

void setup() {
  Serial.begin(115200);
  trafficlight.begin();                // you have to call the .begin() method for the LED pair
  trafficlight.red();                  // you can switch each lamp on individually

  for (auto &obj : button)
  {
    obj.begin();   // you have to call the .begin() method for each button
  }

  // optional member functions

  // by default there are 4 predefined sequences - you can define up to 8
  // you can modify each entry including the durance of each interval (in ms) 
  // for example: in Austria or Ukraine we can add (insert) a green blinking light into the sequence
  //                            index face                             interval
  trafficlight.setSequenceIndex(0,    TrafficlightPin::State::RED,        5000);
  trafficlight.setSequenceIndex(1,    TrafficlightPin::State::REDYELLOW,  3000);
  trafficlight.setSequenceIndex(2,    TrafficlightPin::State::GREEN,      2500);
  trafficlight.setSequenceIndex(3,    TrafficlightPin::State::GREENBLINK, 2500);   // used in Austria or Ukraine
  trafficlight.setSequenceIndex(4,    TrafficlightPin::State::YELLOW,     3000);
  trafficlight.setSequenceMax(5); // now we have total of 5 sequences

  // trafficlight.setInterval(500);         // you can modify the blink speed of the lights
  // trafficlight.setMode(Trafficlight::Mode::AUTOMATIC);  // AUTOMATIC or MANUAL

}

void loop() {
  // read the buttons
  if (button[0].wasPressed()) {
    Serial.println(F("button 0 was pressed"));
    trafficlight.off();                // switch on LED
  }
  if (button[1].wasPressed()) {
    Serial.println(F("button 1 was pressed"));
    trafficlight.red();                // switch off LED
  }
  if (button[2].wasPressed()) {
    Serial.println(F("button 2 was pressed"));
    trafficlight.green();              // if button was pressed, toggle (change state) of LED
  }
  if (button[3].wasPressed()) {
    Serial.println(F("button 3 was pressed"));
    trafficlight.yellow();             // if button was pressed, toggle (change state) of LED
  }

  trafficlight.update();               // you have to call update() for the LED
}
