/*
  Several Effects on the same LED

  The "EffectPin" combines several effects in one class.
  You can switch the shown effect during runtime, for example by button press.
  After switching to another effect you might need to set new intervals.

  This sketch shows that with each button press for led[1] the effect of led[1] will change.

  by noiasca
  2022-12-19 5854/391
*/

#include <Noiasca_led.h>               // download library from http://werner.rothschopf.net/microcontroller/202202_tools_led_en.htm
#include <utility/Noiasca_discrete.h>  // use the discrete pins on the Arduino/Microcontroller

#include <Noiasca_button.h>            // some tools to read buttons

EffectPin led[] {13, 6, 5, 9};         // declare several blinking LED and assign pins
Button button[] {A0, A1, A2, A3};      // button connects pin with GND, "active LOW"

void nextMode(const uint8_t index) {   // switch to next mode
  static uint8_t actual = 0;
  actual++;
  if (actual >= 8) actual = 0;
  // OnOff, Blink, Flicker, Fluorescent, Heartbeat, Pulse, Rhythm, Smooth
  Serial.print(F("LED "));
  Serial.print(index);
  Serial.print(F(" -->"));
  led[index].off();
  switch (actual) {
    case 0:
      led[index].setModeOnOff();
      Serial.println(F("OnOff"));
      break;
    case 1:
      led[index].setModeBlink();
      Serial.println(F("Blink"));
      break;
    case 2:
      led[index].setModeFlicker();
      Serial.println(F("Flicker"));
      break;
    case 3:
      led[index].setModeFluorescent();
      Serial.println(F("Fluorescent"));
      break;
    case 4:
      led[index].setModeHeartbeat();
      Serial.println(F("Heartbeat"));
      break;
    case 5:
      led[index].setModePulse();
      Serial.println(F("Pulse"));
      break;
    case 6:
      led[index].setModeRhythm();
      Serial.println(F("Rhythm"));
      break;
    case 7:
      led[index].off();
      led[index].setModeSmooth();
      Serial.println(F("Smooth"));
      break;
  }
  led[index].on();
}

void setup() {
  Serial.begin(115200);
  for (auto &obj : led) {
    obj.begin();   // you have to call the .begin() method for each LED object
    obj.on();      // you can switch the effect on in setup
  }
  for (auto &obj : button) {
    obj.begin();   // you have to call the .begin() method for each button
  }

  // effects are OnOff, Blink, Flicker, Fluorescent, Heartbeat, Pulse, Rhythm, Smooth
  led[0].setModeRhythm();
  led[1].setModeHeartbeat();
  led[2].setModeBlink();
  led[3].setModeFlicker();

  // you can set different blink intervals for your LEDs
  //led[0].setOnInterval(2000);
  //led[1].setOnInterval(200);
  //led[2].setOffInterval(500);
  //led[3].setOffInterval(200);
}

void loop() {
  // read the buttons
  if (button[0].wasPressed()) {
    Serial.println(F("button 0 was pressed, toggle LED 0"));
    led[0].toggle();                   // switch on LED
  }
  if (button[1].wasPressed()) {
    Serial.println(F("button 1 was pressed, nextMode"));
    nextMode(1);
  }
  if (button[2].wasPressed()) {
    Serial.println(F("button 2 was pressed, toogle LED 2"));
    led[2].toggle();                   // if button was pressed, toggle (change state)
  }
  if (button[3].wasPressed()) {
    Serial.println(F("button 3 was pressed, toogle LED 3"));
    led[3].toggle();                   // if button was pressed, toggle (change state)
  }

  for (auto &obj : led) obj.update();  // you have to call update() for each LED
  // put other non blocking code here, to run repeatedly
}
