/*
  Control LEDs with serial Monitor

  this example shows how to switch on/off several different LEDs with commands over Serial Monitor
    
  some LEDs must be connected to PWM enabled pins! 

  by noiasca
*/

#include <Noiasca_led.h>               // download library from http://werner.rothschopf.net/microcontroller/202202_tools_led_en.htm
#include <utility/Noiasca_discrete.h>  // use the discrete pins on the Arduino/Microcontroller
#include <Noiasca_button.h>            // some tools to read buttons

BlinkPin blinkLed[] {13};
RhythmPin rhythmLed[] {12};
AlternatingPin alternatingLed[] {{2, 4, 500, 500}};        // two LEDs blink vice versa
Bounce5Pin bounce5Led[] {{A0, A1, A2, A3, A4}};
PulsePin pulseLed[] {8};   
GenericPin genericLed[] {7};           // a simple on/off LED
SmoothPin smoothLed[] {3, 5};          // UNO PWM pins 3, 5, 6, 9, 10, 11
FluorescentPin fluorescentLed[] {6, 7, 9};       // UNO PWM pins 3, 5, 6, 9, 10, 11
BeatPin beatLed[] {10};                // UNO PWM pins 3, 5, 6, 9, 10, 11
FlickerPin flickerLed[] {11};          // UNO PWM pins 3, 5, 6, 9, 10, 11

void setup() {
  Serial.begin(115200);
  Serial.println(F("\nStart"));
  for (auto &obj : blinkLed) obj.begin();
  for (auto &obj : rhythmLed) obj.begin();
  for (auto &obj : alternatingLed) obj.begin();
  for (auto &obj : bounce5Led) obj.begin();
  for (auto &obj : pulseLed) obj.begin();
  for (auto &obj : smoothLed) obj.begin();
  for (auto &obj : fluorescentLed) obj.begin();
  for (auto &obj : beatLed) obj.begin();
  for (auto &obj : flickerLed) obj.begin();

  blinkLed[0].set(700, 700);
  blinkLed[0].off();

  rhythmLed[0].on();
  alternatingLed[0].on();
  smoothLed[0].on();
  fluorescentLed[0].on();
  pulseLed[0].on();
  bounce5Led[0].on();
  flickerLed[0].on();
}

void loop() {
  readSerial();

  // you must call the update() method for each object:
  for (auto &obj : blinkLed) obj.update();
  for (auto &obj : rhythmLed) obj.update();
  for (auto &obj : alternatingLed) obj.update();
  for (auto &obj : bounce5Led) obj.update();
  for (auto &obj : smoothLed) obj.update();
  for (auto &obj : pulseLed) obj.update();
  for (auto &obj : fluorescentLed) obj.update();
  for (auto &obj : flickerLed) obj.update();
  for (auto &obj : beatLed) obj.update();
}

// alternative how to switch LEDs via Serial Monitor
void readSerial() {
  if (Serial.available()) {
    char c = Serial.read();
    switch (c) {
      case 'b' : blinkLed[0].toggle(); break;              // toggle the first blink LED
      case 'r' : rhythmLed[0].toggle(); break;
      case 'a' : alternatingLed[0].toggle(); break;
      case '5' : bounce5Led[0].toggle(); break;
      case 'g' : genericLed[0].toggle(); break;
      case 'p' : pulseLed[0].on(); break;
      case 's' : smoothLed[0].toggle(); break;
      case 'f' : fluorescentLed[0].toggle(); break;
      case 'i' : flickerLed[0].toggle(); break;
      case '1' : for (auto &obj : fluorescentLed) obj.on(); break;   // switch on complete group of these LEDs
      case '0' : for (auto &obj : fluorescentLed) obj.off(); break;
    }
  }
}
