/*
  Several LEDs in one Sketch
  

  by noiasca
  2021-12-04
*/

#include <Noiasca_led.h>               // download library from http://werner.rothschopf.net/microcontroller/202202_tools_led_en.htm
#include <utility/Noiasca_discrete.h>  // use the discrete pins on the Arduino/Microcontroller
#include <Noiasca_button.h>            // some tools to read buttons
#incldue <Noiasca_timer.h>

BlinkPin blinkLed[] {13};
RhythmPin rhythmLed[] {12};
AlternatingPin alternatingLed[] {{2, 4, 500, 500}};        // two LEDs blink vice versa
//Bounce5Led bounce5Led[] {{7, 8, 9, 10, 11}};
Bounce5Pin bounce5Led[] {{7, 7, 7, 7, 7}};       // for debug only - all other pins are already used...

SmoothPin smoothLed[] {3};                       // UNO PWM pins 3, 5, 6, 9, 10, 11
FluorescentPin fluorescentLed[] {10, 11};        // UNO PWM pins 3, 5, 6, 9, 10, 11
PulsePin pulseLed[] {6};                         // UNO PWM pins 3, 5, 6, 9, 10, 11
FlickerPin flickerLed[] {5};                     // UNO PWM pins 3, 5, 6, 9, 10, 11

Button button[] {A0, A1, A2, A3};      // button connects pin with GND, "active LOW"

void cbFlickerLed0() {
  flickerLed[0].toggle();
}

void cbFluorescentLeds() {
  for (auto &obj : fluorescentLed) obj.toggle();
}

LittleTimer littleTimer[] {
  {cbFlickerLed0, 3000, 3},
  {cbFluorescentLeds, 5000}
};

void setup() {
  Serial.begin(115200);
  Serial.println(F("\nStart"));
  for (auto &obj : blinkLed) obj.begin();
  for (auto &obj : rhythmLed) obj.begin();
  for (auto &obj : alternatingLed) obj.begin();
  for (auto &obj : bounce5Led) obj.begin();
  for (auto &obj : smoothLed) obj.begin();
  for (auto &obj : fluorescentLed) obj.begin();
  for (auto &obj : pulseLed) obj.begin();
  for (auto &obj : flickerLed) obj.begin();
  for (auto &obj : button) obj.begin();

  blinkLed[0].setInterval(700, 700);
  blinkLed[0].off();

  rhythmLed[0].off();
  alternatingLed[0].off();
  smoothLed[0].off();
  fluorescentLed[0].off();
  pulseLed[0].off();
  bounce5Led[0].off();
  flickerLed[0].on();
}

void loop() {
  if (button[0].wasPressed()) flickerLed[0].toggle();
  if (button[1].wasPressed()) fluorescentLed[0].toggle();  // check button toggle the LED
  if (button[2].wasPressed()) smoothLed[0].toggle();       // check button toggle the LED
  if (button[3].wasPressed()) pulseLed[0].toggle();

  readSerial();

  // you must call the update() method for each object:
  for (auto &obj : blinkLed) obj.update();
  for (auto &obj : rhythmLed) obj.update();
  for (auto &obj : alternatingLed) obj.update();
  for (auto &obj : bounce5Led) obj.update();
  for (auto &obj : smoothLed) obj.update();
  for (auto &obj : pulseLed) obj.update();
  for (auto &obj : fluorescentLed) obj.update();
  for (auto &obj : flickerLed) obj.update();
  for (auto &obj : littleTimer) obj.update();
}

// alternative how to switch LEDs via Serial Monitor
void readSerial() {
  if (Serial.available()) {
    char c = Serial.read();
    switch (c) {
      case 'b' : blinkLed[0].toggle(); break;                        // toggle the first blink LED
      case 'r' : rhythmLed[0].toggle(); break;
      case 'a' : alternatingLed[0].toggle(); break;
      case '5' : bounce5Led[0].toggle(); break;
      case 's' : smoothLed[0].toggle(); break;
      case 'f' : fluorescentLed[0].toggle(); break;
      case 'i' : flickerLed[0].toggle(); break;
      case '1' : for (auto &obj : fluorescentLed) obj.on(); break;   // switch on complete group of these LEDs
      case '0' : for (auto &obj : fluorescentLed) obj.off(); break;
    }
  }
}
