/*
  Smooth LED

  This LED will
  - when switched on: get brighter slowly to the maximum and 
  - when switched off: dimm down slowly to 0
    
  This example uses a PCA9685 / PWM Servo Driver for up to 16 LEDs

  by noiasca
  2022-12-17 OK
*/

#include <Noiasca_led.h>               // download library from https://werner.rothschopf.net/microcontroller/202202_tools_led_en.htm
#include <utility/Noiasca_PCA9685.h>   // needed for PWM Servo Driver
#include <Noiasca_button.h>            // some tools to read buttons
#include <Wire.h>                      // I2C library for the PCA9685
#include <Adafruit_PWMServoDriver.h>   // install with Library Manager
Adafruit_PWMServoDriver pwm = Adafruit_PWMServoDriver(); // create a pwm instance

SmoothPCA9685 smoothLed {pwm, 0};      // one output on your pwm object
Button button[] {A0, A1, A2, A3};      // button connects pin with GND, "active LOW"

void setup() {
  Serial.begin(115200);                          // start Serial interface
  Wire.begin();                                  // start I2C
  pwm.begin();                                   // start PCA9685
  //pwm.setOscillatorFrequency(27000000);        // optional PCA9685 set frequency
  //pwm.setPWMFreq(60);                          // optional PCA PWM frequency between 40 and 1600
  
  smoothLed.begin();                   // you have to call the .begin() method for the LED
  smoothLed.on();                      // you can switch the LED on (optional)
  smoothLed.setOnInterval(30);         // you can modify the delay time for the smoothing (optional)
  smoothLed.setOffInterval(5);         // you can modify the delay time for the smoothing (optional)
  //smoothLed.setMaxBrightness(240);   // you can limit the maximum brightness. Highest value on Arduino is 255. Default 255.
  
  for (auto &obj : button)
  {
    obj.begin();   // you have to call the .begin() method for each button
  }
}

void loop() {
  // read the buttons
  if (button[0].wasPressed())
  {
    Serial.println(F("button 0 was pressed, switch ON LED"));
    smoothLed.on();          // switch on LED
  }
  if (button[1].wasPressed()) {
    Serial.println(F("button 1 was pressed, switch OFF LED"));
    smoothLed.off();         // switch off LED
  }
  if (button[2].wasPressed()) {
    Serial.println(F("button 2 was pressed, toogle LED (change from ON to OFF or vice versa)"));
    smoothLed.toggle();      // if button was pressed, toggle (change state) of blinkLed
  }
  if (button[3].wasPressed()) {
    byte maxBrightness = random(256);
    Serial.print(F("button 3 was pressed, new maxBrightness=")); Serial.println(maxBrightness);
    smoothLed.setMaxBrightness(maxBrightness); // if button was pressed, change maxBrightness
  }

  smoothLed.update();        // you have to call update() for the LED
}
