/*
   Blink LED on a HT16K33
   blinks several LEDs on a HT16K33 LED driver / port expander

   by noiasca

   2023-02-18 ok
*/

#include <Wire.h>                      // I2C class for the port expander
#include <Noiasca_led.h>               // download from: https://werner.rothschopf.net/microcontroller/202202_tools_led_en.htm
#include <utility/Noiasca_HT16K33.h>   // needed to control HT16K33 - part of the LED tool kit

// create a expander object
HT16K33expander myHT16K33(0x76);       // create an expander instance at a specific I2C address (usually between 0x70 - 0x77)

// create your LED objects
// hand over the expander object and the number of LED (0..127)
BlinkHT16K33 blinkLEDA(myHT16K33, 0 + 0);        // a blink LED on a port expander  (first cathode, first Anode)
BlinkHT16K33 blinkLEDB(myHT16K33, 16 + 0);       // a blink LED on a port expander  (second cathode, first Anode)   
BlinkHT16K33 blinkLEDC(myHT16K33, 32 + 2);       // a blink LED on a port expander  (third cathode, third Anode)  

void allLedsOn() {
  // just a short test to switch on all LEDs on the HT16K33 manually
  for (int i = 0; i < 128; i++) myHT16K33.digitalWrite(i, HIGH);
  delay(1000);
  myHT16K33.clear();
  delay(1000);
}

void setup() {
  Serial.begin(115200);
  Serial.println(F("LED & HT16K33 Test"));

  Wire.begin();                        // needed for the HT16K33
  myHT16K33.begin();                   // start the HT16K33 object
  
  blinkLEDA.begin();                   // start the LED object
  blinkLEDB.begin();                   
  blinkLEDC.begin();                   

  blinkLEDA.setOnInterval(250);        // set the on time of a pin
  //blinkLEDB.on();                    // you can switch on or off the effect
  blinkLEDB.setOffInterval(250);       // set the off time of the effect
}

void loop() {
  blinkLEDA.update();                  // call .update() for your object
  blinkLEDB.update();
  blinkLEDC.update();
}
