/*
   Miscellanous Effects on several LEDs with a HT16K33

   This just demostrates how to display miscellanous effects on LEDs connected to a HT16K33

   by noiasca

   2023-02-18
*/

#include <Wire.h>                      // I2C class for the port expander
#include <Noiasca_led.h>               // download from: https://werner.rothschopf.net/microcontroller/202202_tools_led_en.htm
#include <utility/Noiasca_HT16K33.h>   // needed to control HT16K33 - part of the LED tool kit

// create a expander object
HT16K33expander myHT16K33(0x76);       // create an expander instance at a specific I2C address (usually between 0x70 - 0x77)

// let's create several miscellouns objects: 
// hand over the expander object and the number of LED (0..127)
BlinkHT16K33 blink[] {
  {myHT16K33, 0 + 0},        // cathode 0, anode 0
  {myHT16K33, 0 + 1},
  {myHT16K33, 0 + 2},
};

RhythmHT16K33 rhythm[] {
  {myHT16K33, 1 * 16 + 0},
  {myHT16K33, 1 * 16 + 1},
  {myHT16K33, 1 * 16 + 2},   // cathode 1, anode 2
};

AlternatingHT16K33 alternating[] {
  {myHT16K33, 2 * 16 + 0},
  {myHT16K33, 2 * 16 + 2},
  {myHT16K33, 2 * 16 + 4},
};

// it is also an array, but only one index/one object 
Bounce5HT16K33 bounce5[] {
  {myHT16K33, 3 * 16 + 0},   // needs 5 consecutive pins on ONE cathode
};

// due to missing PWM these effects have limited capabilities:
FlickerHT16K33 flicker[] {
  {myHT16K33, 4 * 16 + 0},
  {myHT16K33, 4 * 16 + 1},
  {myHT16K33, 4 * 16 + 2},
};

PulseHT16K33 pulse[] {
  {myHT16K33, 5 * 16 + 0},
  {myHT16K33, 5 * 16 + 1},
  {myHT16K33, 5 * 16 + 2},
};

FluorescentHT16K33 fluorescent[] {
  {myHT16K33, 6 * 16 + 0},
  {myHT16K33, 6 * 16 + 3},
  {myHT16K33, 6 * 16 + 6},
};

void setup() {
  Wire.begin();                        // needed for the HT16K33
  myHT16K33.begin();                   // start the HT16K33 object

  randomSeed(analogRead(A1));

  for (auto &i : blink) {
    i.begin();
    i.setOnInterval(random(100, 1000));          // randomize the on time of a pin
    i.setOffInterval(random(100, 1000));         // randomize the off time of a pin
  }

  for (auto &i : rhythm) {
    i.begin();
    i.setInterval(random(10, 500), random(10, 500), random(10, 500), random(100, 500));   // randomize the on time of a pin
  }

  for (auto &i : alternating) {
    i.begin();
    i.setOnInterval(random(100, 500));
  }

  for (auto &i : bounce5) i.begin();

  for (auto &i : flicker) {
    i.begin();
    i.on();
  }

  for (auto &i : pulse) {
    i.begin();
    i.setOnInterval(random(1000, 5000));
    i.on();
  }

  for (auto &i : fluorescent) {
    i.begin();
    i.on();
  }
}

void loop() {
  for (auto &i : blink) i.update();    // call .update() for your object
  for (auto &i : rhythm) i.update();
  for (auto &i : alternating) i.update();
  for (auto &i : bounce5) i.update();

  for (auto &i : flicker) i.update();
  for (auto &i : pulse) i.update();
  for (auto &i : fluorescent) i.update();
}
