/*
  Timer with limit

  A timer will run for a specific amount of iterations
  you can restart it

  by noiasca
  2022-02-09 - 3468/268
*/

#include <Noiasca_led.h>               // download library from http://werner.rothschopf.net/microcontroller/202202_tools_led_en.htm
#include <utility/Noiasca_discrete.h>  // use the discrete pins on the Arduino/Microcontroller
#include <Noiasca_button.h>            // some tools to read buttons
#include <Noiasca_timer.h>

BlinkPin blinkLed {13};                // this LED effect will be switched on and off with the timer
HeartbeatPin activeIndicator {6};      // lets use a heartbeat LED as indicator that the timer is active / is running

Button button {A0};                    // button to restart the timer

// here you create your timer object
// you need two parameters:
// the first parameter is the interval
// the optional second parameter is a limit how often you want that trigger
//                      interval limit
LittleTimer littleTimer {3000,   5};

void setup() {
  Serial.begin(115200);
  Serial.println(F("\nStart"));
  button.begin();
  blinkLed.begin();                    // start a LED object
  activeIndicator.begin();             // start a LED object
  activeIndicator.setInterval(10);     // make the effect faster
  activeIndicator.setMinBrightness(127);         // don't dimm to zero

  littleTimer.start();
}

void loop() {
  // you must call the update() method for each object:
  blinkLed.update();
  activeIndicator.update();
  littleTimer.update();                // if the defined time is over, the timer will trigger the callback function

  if (littleTimer.hasTriggered()) {    // fires each time enough when enough time has passed
    Serial.println(F("timer has triggered"));
    blinkLed.toggle();
  }

  if (littleTimer.hasEnded()) {        // fires one time after the timer has ended
    Serial.println(F("timer has ended"));
    activeIndicator.off();
    blinkLed.off();
  }

  if (button.wasPressed()) {
    Serial.println(F("Button was pressed"));
    blinkLed.on();
    littleTimer.start();               // you can restart your timer
  }
}
