/*
  Two Smooth LED in Sync

  Kombination of LED effects with a timer
  The two LEDs will 
  - smoothly blink in a pattern Both on - off - A on - off - B on - off

  you must connect the LED to a PWM enabled PIN

  by noiasca
  2022-02-14   used in https://forum.arduino.cc/t/arduiono-projekt-fur-modellbau/953992/35
*/

#include <Noiasca_led.h>               // download library from https://werner.rothschopf.net/microcontroller/202202_tools_led_en.htm
#include <utility/Noiasca_discrete.h>  // use the discrete pins on the Arduino/Microcontroller
#include <Noiasca_timer.h>

SmoothPin smoothLedA {10};             // UNO PWM pins 3, 5, 6, 9, 10, 11
SmoothPin smoothLedB {11};

// here you create your timer object
// you set one parameters: the intervall in milliseconds
LittleTimer littleTimer {750};

void setup() {
  Serial.begin(115200);
  smoothLedA.begin();                  // you have to call the .begin() method for the LED pair
  smoothLedB.begin();                  // you have to call the .begin() method for the LED pair

  //smoothLedA.on();                   // switch the LED on
  //smoothLedA.off();                  // switch the LED off
  smoothLedA.setOnInterval(10);        // modify the delay time for the smothing
  smoothLedB.setOnInterval(10);
  //smoothLedA.setOffInterval(5);      // modify the delay time for the smothing
  //smoothLedA.setMaxBrightness(240);  // limit the maximum brightness. Highest value on Arduino is 255. Default 255.
}

void loop() {
  // AB, off, off, A, off, off, B, off, off

  static byte state = 0;
  if (littleTimer.hasTriggered()) {
    if (state < 8)
      state++;
    else
      state = 0;
    switch (state) {
      case 0 :
        smoothLedA.on();
        smoothLedB.on();
        break;
      case 1 :
      case 2 :
        smoothLedA.off();
        smoothLedB.off();
        break;
      case 3 :
        smoothLedA.on();
        break;
      case 4:
      case 5:
        smoothLedA.off();
        smoothLedB.off();
        break;
      case 6 :
        smoothLedB.on();
        break;
      case 7 :
      case 8:
        smoothLedA.off();
        smoothLedB.off();
        break;
    }
  }
  smoothLedA.update();                 // you have to call update() for the LED
  smoothLedB.update();
}
